pub fn probe_capabilities(path: &Path) -> Arc<Capabilities>Expand description
Detect filesystem and hardware capabilities for a path (cached per mount point)
pub fn probe_capabilities(path: &Path) -> Arc<Capabilities>Detect filesystem and hardware capabilities for a path (cached per mount point)